bebi103: Utilities for Caltech BE/Bi 103 ab courses
===================================================

The bebi103 package provides convenience functions for use in the `BE/Bi 103 ab courses <http://bebi103.caltech.edu/>`_ at `Caltech <http://caltech.edu/>`_.


.. toctree::
   :maxdepth: 1
   :caption: Getting started

   getting_started/installation
   getting_started/purpose


.. toctree::
   :maxdepth: 2
   :caption: User guide

   user_guide/using_user_guide.ipynb
   user_guide/hv.ipynb
   user_guide/bootstrap.ipynb
   user_guide/stan.ipynb
   user_guide/image.ipynb
   user_guide/api


.. toctree::
   :maxdepth: 1
   :caption: Credits and citation

   credits_and_citation.rst

